@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -46,7 +46,7 @@ def main():
     for item in backup['PhonePhonebook']:
         item['MemoryType'] = memory
         loc = state_machine.AddMemory(item)
-        print(('Added item to location %d' % loc))
+        print(('Added item to location {0:d}'.format(loc)))
 
 
 if __name__ == '__main__':
