@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ import gammu
 import sys
 
 state_machine = gammu.StateMachine()
-if len(sys.argv) >= 2:
+if len(sys.argv) > 2:
     state_machine.ReadConfig(Filename=sys.argv[1])
     del sys.argv[1]
 else:
@@ -37,4 +37,4 @@ status = state_machine.GetBatteryCharge()
 
 for x in status:
     if status[x] != -1:
-        print(("%20s: %s" % (x, status[x])))
+        print(("{0:20}: {1}".format(x, status[x])))
