@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -54,9 +54,9 @@ def main():
         remain = remain - 1
 
         print()
-        print('%-15s: %d' % ('Location', entry['Location']))
+        print('{0:<15}: {1:d}'.format('Location', entry['Location']))
         for v in entry['Entries']:
-            print('%-15s: %s' % (v['Type'], str(v['Value'])))
+            print('{0:<15}: {1}'.format(v['Type'], str(v['Value'])))
 
 
 if __name__ == '__main__':
