@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,10 +49,10 @@ def main():
 
             for m in sms:
                 print()
-                print('%-15s: %s' % ('Number', m['Number']))
-                print('%-15s: %s' % ('Date', str(m['DateTime'])))
-                print('%-15s: %s' % ('State', m['State']))
-                print('\n%s' % m['Text'])
+                print('{0:<15}: {1}'.format('Number', m['Number']))
+                print('{0:<15}: {1}'.format('Date', str(m['DateTime'])))
+                print('{0:<15}: {1}'.format('State', m['State']))
+                print('\n{0}'.format(m['Text']))
     except gammu.ERR_EMPTY:
         # This error is raised when we've reached last entry
         # It can happen when reported status does not match real counts
