@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -58,21 +58,21 @@ for x in data:
 
     m = x[0]
     print()
-    print('%-15s: %s' % ('Number', m['Number']))
-    print('%-15s: %s' % ('Date', str(m['DateTime'])))
-    print('%-15s: %s' % ('State', m['State']))
-    print('%-15s: %s' % ('Folder', m['Folder']))
-    print('%-15s: %s' % ('Validity', m['SMSC']['Validity']))
+    print('{0:<15}: {1}'.format('Number', m['Number']))
+    print('{0:<15}: {1}'.format('Date', str(m['DateTime'])))
+    print('{0:<15}: {1}'.format('State', m['State']))
+    print('{0:<15}: {1}'.format('Folder', m['Folder']))
+    print('{0:<15}: {1}'.format('Validity', m['SMSC']['Validity']))
     loc = []
     for m in x:
         loc.append(str(m['Location']))
-    print('%-15s: %s' % ('Location(s)', ', '.join(loc)))
+    print('{0:<15}: {1}'.format('Location(s)', ', '.join(loc)))
     if v is None:
-        print('\n%s' % m['Text'])
+        print('\n{0}'.format(m['Text']))
     else:
         for e in v['Entries']:
             print()
-            print('%-15s: %s' % ('Type', e['ID']))
+            print('{0:<15}: {1}'.format('Type', e['ID']))
             if e['Bitmap'] is not None:
                 for bmp in e['Bitmap']:
                     print('Bitmap:')
