@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -45,4 +45,4 @@ for number in sys.argv[2:]:
     try:
         state_machine.SendSMS(message)
     except gammu.GSMError as exc:
-        print('Sending to %s failed: %s' % (number, exc))
+        print('Sending to {0} failed: {1}'.format(number, exc))
