@@ -2,9 +2,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -37,13 +37,13 @@ def callback(state_machine, callback_type, data):
     '''
     global REPLY
     if callback_type != 'USSD':
-        print('Unexpected event type: %s' % callback_type)
+        print('Unexpected event type: {0}'.format(callback_type))
         sys.exit(1)
 
     REPLY = True
 
     print('Network reply:')
-    print('Status: %s' % data['Status'])
+    print('Status: {0}'.format(data['Status']))
     print(data['Text'])
 
     if data['Status'] == 'ActionNeeded':
