@@ -1,6 +1,6 @@
 /*
  * python-gammu - Phone communication libary
- * Copyright (C) 2003 - 2016 Michal Čihař
+ * Copyright (C) 2003 - 2018 Michal Čihař
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,6 +28,19 @@
 /* PRINTF_STYLE definition */
 #include <gammu-misc.h>
 
+#include <gammu-config.h>
+
+#define STR1(x)  #x
+#define STR(x)  STR1(x)
+
+#define PYTHON_GAMMU_VERSION STR(PYTHON_GAMMU_MAJOR_VERSION) "." STR(PYTHON_GAMMU_MINOR_VERSION)
+
+#ifndef HAVE_STRCASECMP
+#ifdef HAVE_STRICMP
+#define strcasecmp _stricmp
+#endif
+#endif
+
 /**
  * Copies at most n chars from src to dest, dest will be \0 terminated.
  */
