@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@
 import unittest
 import tempfile
 import gammu
+import os
 from .test_sms import PDU_DATA
 
 
@@ -91,32 +92,38 @@ class DebugTest(unittest.TestCase):
     def setUp(self):
         gammu.SetDebugLevel('textall')
 
-    def check_operation(self, filename):
+    def check_operation(self, filename, handle=None):
         """
         Executes gammu operation which causes debug logs.
         """
         gammu.DecodePDU(PDU_DATA)
+        gammu.SetDebugFile(None)
+        if handle:
+            handle.close()
         if filename is not None:
             with open(filename, 'r') as handle:
                 self.assertTrue('SMS type: Status report' in handle.read())
 
     def test_file(self):
-        testfile = tempfile.NamedTemporaryFile(suffix='.debug')
+        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
+        testfile.close()
         try:
-            gammu.SetDebugFile(testfile.file)
-            self.check_operation(testfile.name)
+            handle = open(testfile.name, 'w')
+            gammu.SetDebugFile(handle)
+            self.check_operation(testfile.name, handle)
         finally:
             gammu.SetDebugFile(None)
-            testfile.close()
+            os.unlink(testfile.name)
 
     def test_filename(self):
-        testfile = tempfile.NamedTemporaryFile(suffix='.debug')
+        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
+        testfile.close()
         try:
             gammu.SetDebugFile(testfile.name)
             self.check_operation(testfile.name)
         finally:
             gammu.SetDebugFile(None)
-            testfile.close()
+            os.unlink(testfile.name)
 
     def test_none(self):
         gammu.SetDebugFile(None)
@@ -124,12 +131,13 @@ class DebugTest(unittest.TestCase):
 
     def test_nothing(self):
         gammu.SetDebugLevel('nothing')
-        testfile = tempfile.NamedTemporaryFile(suffix='.debug')
+        testfile = tempfile.NamedTemporaryFile(suffix='.debug', delete=False)
+        testfile.close()
         try:
-            gammu.SetDebugFile(testfile.file)
+            gammu.SetDebugFile(testfile.name)
             self.check_operation(None)
             with open(testfile.name, 'r') as handle:
                 self.assertEqual('', handle.read())
         finally:
             gammu.SetDebugFile(None)
-            testfile.close()
+            os.unlink(testfile.name)
