@@ -1,9 +1,9 @@
 # -*- coding: UTF-8 -*-
 # vim: expandtab sw=4 ts=4 sts=4:
 #
-# Copyright © 2003 - 2016 Michal Čihař <michal@cihar.com>
+# Copyright © 2003 - 2018 Michal Čihař <michal@cihar.com>
 #
-# This file is part of python-gammu <http://wammu.eu/python-gammu/>
+# This file is part of python-gammu <https://wammu.eu/python-gammu/>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@ import gammu
 import tempfile
 import shutil
 import datetime
+import platform
 import os.path
 
 DUMMY_DIR = os.path.join(os.path.dirname(__file__), 'data', 'gammu-dummy')
@@ -56,6 +57,7 @@ class DummyTest(unittest.TestCase):
     config_name = None
     dummy_dir = None
     _called = False
+    _state_machine = None
 
     def setUp(self):
         self.test_dir = tempfile.mkdtemp()
@@ -66,12 +68,15 @@ class DummyTest(unittest.TestCase):
             handle.write(CONFIGURATION.format(path=self.test_dir))
 
     def tearDown(self):
+        if self._state_machine:
+            self._state_machine.Terminate()
         shutil.rmtree(self.test_dir)
 
     def get_statemachine(self):
         state_machine = gammu.StateMachine()
         state_machine.ReadConfig(Filename=self.config_name)
         state_machine.Init()
+        self._state_machine = state_machine
         return state_machine
 
     def fake_incoming_call(self):
@@ -353,6 +358,26 @@ class BasicDummyTest(DummyTest):
         state_machine.AddFolder('', 'testfolder')
         state_machine.DeleteFolder('testfolder')
 
+    @unittest.skipIf(platform.system() == 'Windows',
+        'Not supported on Windows')
+    def test_emoji_folder(self):
+        state_machine = self.get_statemachine()
+        name = 'test-😘'
+        self.assertRaises(
+            gammu.ERR_FILENOTEXIST,
+            state_machine.DeleteFolder,
+            name
+        )
+        self.assertEqual(
+            name,
+            state_machine.AddFolder('', name)
+        )
+        # Check the folder exists as expected on filesystem
+        self.assertTrue(
+            os.path.exists(os.path.join(self.dummy_dir, 'fs', name))
+        )
+        state_machine.DeleteFolder(name)
+
     def test_addfile(self):
         state_machine = self.get_statemachine()
         file_stat = os.stat(TEST_FILE)
